from setuptools import setup

setup(name='distributions_mudassar',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_mudassar'],
      author= 'Mudassar Hanif',
      author_email= 'mudassarhanif2@gmail.com',
      zip_safe=False)
